OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Du skapade teamet {circle}",
    "{author} created the team {circle}" : "{author} skapade teamet {circle}",
    "You deleted {circle}" : "Du tog bort {circle}",
    "{author} deleted {circle}" : "{author} tog bort {circle}",
    "You made {member} join {circle}" : "Du fick {member} att gå med i {circle}",
    "{author} made {member} join {circle}" : "{author} fick {member} att gå med i {circle}",
    "You added team {member} as member to {circle}" : "Du lade till team {member} som medlem till {circle}",
    "{author} added team {member} as member to {circle}" : "{author} lade till team {member} som medlem i {circle}",
    "You made {member} leave {circle}" : "Du fick {member} att lämna {circle}",
    "{author} made {member} leave {circle}" : "{author} fick {member} att lämna {circle}",
    "You removed {member} from {circle}" : "Du tog bort {member} från {circle}",
    "{author} removed {member} from {circle}" : "{author} tog bort {member} från {circle}",
    "You joined {circle}" : "Du gick med i {circle}",
    "{member} joined {circle}" : "{member} gick med i {circle}",
    "You accepted the invitation to join {circle}" : "Du accepterade inbjudan att gå med i {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} accepterade inbjudan att gå med i {circle}",
    "You added {member} as member to {circle}" : "Du lade till {member} som medlem till {circle}",
    "You have been added as member to {circle} by {author}" : "Du har lagts till som medlem i {circle} av {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} har lagts till som medlem till {circle} av {author}",
    "You added {external} to {circle}" : "Du lade till {external} till {circle}",
    "{external} has been added to {circle} by {author}" : "{external} har lagts till {circle} av {author}",
    "You accepted {member}'s request to join {circle}" : "Du accepterade {member}s begäran att gå med i {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Din begäran att gå med i {circle} har accepterats av {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}s begäran att gå med i {circle} har accepterats av {author}",
    "You left {circle}" : "Du lämnade {circle}",
    "{member} left {circle}" : "{member} lämnade {circle}",
    "You declined the invitation to join {circle}" : "Du avslog inbjudan att gå med i {circle}",
    "{member} declined an invitation to join {circle}" : "{member} avslog inbjudan att gå med i {circle}",
    "You cancelled your request to join {circle}" : "Du avbröt din begäran att gå med i {circle}",
    "{member} cancelled a request to join {circle}" : "{member} avbröt sin begäran att gå med i {circle}",
    "You have been removed from {circle} by {author}" : "Du har tagits bort från {circle} av {author}",
    "{member} has been removed from {circle} by {author}" : "{member} har tagits bort från {circle} av {author}",
    "You removed {external} from {circle}" : "Du tog bort {external} från {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} har tagits bort från {circle} av {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Du avbröt {member}s inbjudan att gå med i {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Din inbjudan att gå med i {circle} har avbrutits av {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} avbröt {member}s inbjudan att gå med i {circle}",
    "You dismissed {member}'s request to join {circle}" : "Du avslog {member}s begäran att gå med i {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Din begäran att gå med i {circle} har avslagits av {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}s begäran att gå med i {circle} har avslagits av {author}",
    "You invited {member} to join {circle}" : "Du bjöd in {member} att gå med i {circle}",
    "You have been invited to join {circle} by {author}" : "Du har bjudits in att gå med i {circle} av {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} har bjudits in att gå med i {circle} av {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Du ändrade {member}s nivå i {circle} till %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ändrade din nivå i {circle} till %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ändrade {member}s nivå i {circle} till %1$s",
    "You sent a request to join {circle}" : "Du skickade en begäran att gå med i {circle}",
    "{member} sent a request to join {circle}" : "{member} skickade en begäran att gå med i {circle}",
    "You are the new owner of {circle}" : "Du är ny ägare av {circle}",
    "{member} is the new owner of {circle}" : "{member} är ny ägare av {circle}",
    "Teams" : "Teams",
    "On events happening in a <strong>team</strong> of which you are a member" : "Vid händelser i ett <strong>team</strong> där du är medlem",
    "Any important event in a <strong>team</strong> you are moderating" : "Alla viktiga händelser i ett <strong>team</strong> du modererar",
    "On global events happening in any <strong>team</strong>" : "Vid globala händelser som händer i något <strong>team</strong>",
    "Single" : "Singel",
    "Personal" : "Personlig",
    "System" : "System",
    "Visible" : "Synlig",
    "Open" : "Öppen",
    "Invite" : "Bjud in",
    "Join request" : "Anslutningsförfrågan",
    "Friends" : "Vänner",
    "Password protected" : "Lösenordsskyddad",
    "No Owner" : "Ingen ägare",
    "Hidden" : "Gömd",
    "Backend" : "Backend",
    "Local" : "Lokal",
    "Root" : "Rot",
    "Team invite" : "Teaminbjudan",
    "Federated" : "Federerad",
    "Mount point" : "Monteringspunkt",
    "Nextcloud Account" : "Nextcloudkonto",
    "Nextcloud Group" : "Nextcloud-grupp",
    "Email address" : "E-postadress",
    "Contact" : "Kontakta",
    "Team" : "Team",
    "Nextcloud App" : "Nextcloud-app",
    "Teams App" : "Teams App",
    "Admin Command Line" : "Kommandoraden för administratörer",
    "Member" : "Medlem",
    "Moderator" : "Moderator",
    "Admin" : "Administratör",
    "Owner" : "Ägare",
    "%s shared »%s« with you." : "%s delade \"%s\" med dig.",
    "%s shared »%s« with \"%s\"." : "%s delade \"%s\" med \"%s\".",
    "%s on %s" : "%s på %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delade \"%2$s\" med dig.\nDu bör redan ha fått ett separat e-postmeddelande med en länk för åtkomst.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s delade \"%2$s\" med dig. Du bör redan ha fått ett separat e-postmeddelande med en länk för åtkomst.",
    "Password to access »%1$s« shared to you by %2$s" : "Lösenord för åtkomst till \"%1$s\" delad med dig av %2$s",
    "Password to access »%s«" : "Lösenord för åtkomst till \"%s\"",
    "It is protected with the following password:" : "Den är skyddad med följande lösenord:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klicka på knappen nedan för att öppna det.",
    "Open »%s«" : "Öppna \"%s\"",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s delade flera filer med dig.\nDu borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s delade flera filer med dig. Du borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.",
    "Password to access files shared to you by %1$s" : "Lösenord för åtkomst till filer delade med dig av %1$s",
    "Password to access files" : "Lösenord för åtkomst till filer",
    "%s shared multiple files with \"%s\"." : "%s delade flera filer med \"%s\".",
    "%s shared multiple files with you." : "%s delade flera filer med dig.",
    "Boot up" : "Uppstart",
    "Nextcloud Initialization" : "Nextcloud-initiering",
    "Circles App Initialization" : "Cirklar appinitiering",
    "Fresh installation status" : "Nyinstallationsstatus",
    "Building Local Database" : "Bygger lokal databas",
    "Adding local users and moderators" : "Lägger till lokala användare och moderatorer ",
    "Show all teams" : "Visa alla team",
    "Create a new team" : "Skapa ett nytt team",
    "Files" : "Filer",
    "The team is not federated" : "Detta team är inte federerat",
    "You cannot join this team" : "Du kan inte gå med i detta team",
    "This member is not a moderator" : "Medlemmen är inte en moderator",
    "Insufficient privileges" : "Otillräckliga privilegier",
    "This member does not exist" : "Medlemmen finns inte",
    "This member is the owner of the team" : "Denna medlem är ägaren av teamet",
    "Level cannot be changed for this type of member" : "Nivå kan inte ändras för medlemstypen",
    "%s (Team owned by %s)" : "%s (Team ägs av %s)",
    "You are now a member of the Team \"%2$s\"" : "Du är nu medlem i Team \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Du har blivit inbjuden av %1$s till Team \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s skickade en förfrågan att bli medlem i Team \"%2$s\"",
    "Accept" : "Acceptera",
    "Refuse" : "Neka",
    "Leave the team" : "Lämna team",
    "%s" : "%s",
    "Personal team" : "Personligt team",
    "%s owned by %s" : "%s ägd av %s",
    "You have no permission to create a new team" : "Du har inte behörighet att skapa ett nytt team",
    "%s shared a file with \"%s\"." : "%s delade en fil med \"%s\".",
    "%s shared a file with you." : "%s delade en fil med dig.",
    "%1$s shared %2$s with %3$s" : "%1$s delade %2$s med %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s delade %2$s med \"%3$s\"",
    "Open %s" : "Öppna %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delade innehåll med dig.\nDu borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delade innehåll med dig. Du borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.",
    "Password to access content shared with you by %1$s" : "Lösenord för tillgång till innehåll delat med dig av 1%1$s",
    "Password to access content" : "Lösenord för att komma åt innehåll",
    "This item is already shared with this team" : "Detta objektet delas redan med detta team",
    "Bring cloud-users closer together." : "För moln-användare närmare varandra.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams låter användare att skapa egna grupper av användare/kollegor/vänner.\nDessa grupper av användare kan sedan användas av alla andra appar vid delning.",
    "Failed to load teams" : "Kunde inte läsa in team",
    "Try again" : "Försök igen",
    "No teams found" : "Inga team hittades",
    "Join or create teams to see them here." : "Gå med i eller skapa team för att se dem här.",
    "Create your first team" : "Skapa ditt första team",
    "Loading…" : "Laddar...",
    "More teams" : "Fler team",
    "No files in here" : "Inga filer här",
    "No entries found in this folder" : "Inga objekt funna i denna mapp",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "Shared to Circles" : "Delad med Cirklar",
    "Testing Basic Circle Creation" : "Testar grundläggande Cirkel-skapande",
    "This feature is not available for personal circles" : "Funktionen är inte tillgänglig för personliga cirklar",
    "You are already a member of this circle" : "Du är redan medlem i denna cirkel",
    "You have been blocked from this circle" : "Du har blockerats från denna cirkel",
    "The account is already a member of this circle" : "Kontot är redan medlem av denna cirkel",
    "The account has already been invited into this circle" : "Kontot har redan bjudits in till denna cirkel"
},
"nplurals=2; plural=(n != 1);");
